import { NetlifyInfo } from './platform/netlify';
export interface LogEvent {
    level: string;
    message: string;
    fields: any;
    _time: string;
    request?: RequestReport;
    platform?: PlatformInfo;
    vercel?: PlatformInfo;
    netlify?: NetlifyInfo;
}
export declare enum LogLevel {
    debug = 0,
    info = 1,
    warn = 2,
    error = 3,
    off = 100
}
export interface RequestReport {
    startTime: number;
    statusCode?: number;
    ip?: string | null;
    region?: string | null;
    path: string;
    host?: string | null;
    method: string;
    scheme: string;
    userAgent?: string | null;
}
export interface PlatformInfo {
    environment?: string;
    region?: string;
    route?: string;
    source?: string;
}
export type LoggerConfig = {
    args?: {
        [key: string]: any;
    };
    logLevel?: LogLevel;
    autoFlush?: boolean;
    source?: string;
    req?: any;
};
export declare class Logger {
    initConfig: LoggerConfig;
    logEvents: LogEvent[];
    throttledSendLogs: (this: any) => void;
    children: Logger[];
    logLevel: LogLevel;
    config: LoggerConfig;
    constructor(initConfig?: LoggerConfig);
    debug: (message: string, args?: {
        [key: string]: any;
    }) => void;
    info: (message: string, args?: {
        [key: string]: any;
    }) => void;
    warn: (message: string, args?: {
        [key: string]: any;
    }) => void;
    error: (message: string, args?: {
        [key: string]: any;
    }) => void;
    with: (args: {
        [key: string]: any;
    }) => Logger;
    withRequest: (req: any) => Logger;
    _log: (level: LogLevel, message: string, args?: {
        [key: string]: any;
    }) => void;
    attachResponseStatus: (statusCode: number) => void;
    sendLogs(): Promise<any>;
    flush: any;
}
export declare const log: Logger;
export declare function prettyPrint(ev: LogEvent): void;
