"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const shared_1 = require("../shared");
// This is the generic config class for all platforms that doesn't have a special
// implementation (e.g: vercel, netlify). All config classes extends this one.
class GenericConfig {
    constructor() {
        this.proxyPath = '/_axiom';
        this.isBrowser = typeof window !== 'undefined';
        this.shouldSendEdgeReport = false;
        this.token = process.env.NEXT_PUBLIC_AXIOM_TOKEN || process.env.AXIOM_TOKEN;
        this.dataset = process.env.NEXT_PUBLIC_AXIOM_DATASET || process.env.AXIOM_DATASET;
        this.environment = process.env.NODE_ENV;
        this.axiomUrl = process.env.NEXT_PUBLIC_AXIOM_URL || process.env.AXIOM_URL || 'https://api.axiom.co';
        this.region = process.env.REGION || undefined;
    }
    isEnvVarsSet() {
        return !!(this.axiomUrl && this.dataset && this.token);
    }
    getIngestURL(_) {
        return `${this.axiomUrl}/api/v1/datasets/${this.dataset}/ingest`;
    }
    getLogsEndpoint() {
        return this.isBrowser ? `${this.proxyPath}/logs` : this.getIngestURL(shared_1.EndpointType.logs);
    }
    getWebVitalsEndpoint() {
        return this.isBrowser ? `${this.proxyPath}/logs` : this.getIngestURL(shared_1.EndpointType.webVitals);
    }
    wrapWebVitalsObject(metrics) {
        return metrics.map(m => ({
            webVital: m,
            _time: new Date().getTime(),
            platform: {
                environment: this.environment,
                source: 'web-vital',
            },
        }));
    }
    injectPlatformMetadata(logEvent, source) {
        logEvent.platform = {
            environment: this.environment,
            region: this.region,
            source: source + '-log',
        };
    }
    generateRequestMeta(req) {
        return {
            startTime: new Date().getTime(),
            path: req.url,
            method: req.method,
            host: this.getHeaderOrDefault(req, 'host', ''),
            userAgent: this.getHeaderOrDefault(req, 'user-agent', ''),
            scheme: 'https',
            ip: this.getHeaderOrDefault(req, 'x-forwarded-for', ''),
            region: this.region,
        };
    }
    getHeaderOrDefault(req, headerName, defaultValue) {
        return req.headers[headerName] ? req.headers[headerName] : defaultValue;
    }
}
exports.default = GenericConfig;
//# sourceMappingURL=generic.js.map