"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withAxiom = exports.withAxiomRouteHandler = exports.withAxiomNextConfig = void 0;
const config_1 = require("./config");
const logger_1 = require("./logger");
const shared_1 = require("./shared");
function withAxiomNextConfig(nextConfig) {
    return Object.assign(Object.assign({}, nextConfig), { rewrites: () => __awaiter(this, void 0, void 0, function* () {
            var _a;
            const rewrites = yield ((_a = nextConfig.rewrites) === null || _a === void 0 ? void 0 : _a.call(nextConfig));
            const webVitalsEndpoint = config_1.config.getIngestURL(shared_1.EndpointType.webVitals);
            const logsEndpoint = config_1.config.getIngestURL(shared_1.EndpointType.logs);
            if (!webVitalsEndpoint && !logsEndpoint) {
                const log = new logger_1.Logger();
                log.warn('axiom: Envvars not detected. If this is production please see https://github.com/axiomhq/next-axiom for help');
                log.warn('axiom: Sending Web Vitals to /dev/null');
                log.warn('axiom: Sending logs to console');
                return rewrites || []; // nothing to do
            }
            const axiomRewrites = [
                {
                    source: `${config_1.config.proxyPath}/web-vitals`,
                    destination: webVitalsEndpoint,
                    basePath: false,
                },
                {
                    source: `${config_1.config.proxyPath}/logs`,
                    destination: logsEndpoint,
                    basePath: false,
                },
            ];
            if (!rewrites) {
                return axiomRewrites;
            }
            else if (Array.isArray(rewrites)) {
                return rewrites.concat(axiomRewrites);
            }
            else {
                rewrites.afterFiles = (rewrites.afterFiles || []).concat(axiomRewrites);
                return rewrites;
            }
        }) });
}
exports.withAxiomNextConfig = withAxiomNextConfig;
function withAxiomRouteHandler(handler) {
    return (req) => __awaiter(this, void 0, void 0, function* () {
        var _a, _b;
        let region = '';
        if ('geo' in req) {
            region = (_b = (_a = req.geo) === null || _a === void 0 ? void 0 : _a.region) !== null && _b !== void 0 ? _b : '';
        }
        const report = {
            startTime: new Date().getTime(),
            path: req.url,
            method: req.method,
            host: req.headers.get('host'),
            userAgent: req.headers.get('user-agent'),
            scheme: 'https',
            ip: req.headers.get('x-forwarded-for'),
            region,
        };
        const isEdgeRuntime = globalThis.EdgeRuntime ? true : false;
        const logger = new logger_1.Logger({ req: report, source: isEdgeRuntime ? 'edge' : 'lambda' });
        const axiomContext = req;
        axiomContext.log = logger;
        try {
            const result = yield handler(axiomContext);
            yield logger.flush();
            if (isEdgeRuntime) {
                logEdgeReport(report);
            }
            return result;
        }
        catch (error) {
            logger.error('Error in Next route handler', { error });
            logger.attachResponseStatus(500);
            yield logger.flush();
            if (isEdgeRuntime) {
                logEdgeReport(report);
            }
            throw error;
        }
    });
}
exports.withAxiomRouteHandler = withAxiomRouteHandler;
function logEdgeReport(report) {
    console.log(`AXIOM_EDGE_REPORT::${JSON.stringify(report)}`);
}
function isNextConfig(param) {
    return typeof param == 'object';
}
function withAxiom(param) {
    if (typeof param == 'function') {
        return withAxiomRouteHandler(param);
    }
    else if (isNextConfig(param)) {
        return withAxiomNextConfig(param);
    }
    return withAxiomRouteHandler(param);
}
exports.withAxiom = withAxiom;
//# sourceMappingURL=withAxiom.js.map